accessibilityLabel property
String
get
accessibilityLabel
A short label naming the kind of chart, e.g. "Line chart", for semantics.
Implementation
String get accessibilityLabel => 'Chart';
A short label naming the kind of chart, e.g. "Line chart", for semantics.
String get accessibilityLabel => 'Chart';