ChartText class abstract final

Text-alignment offset math: converts an HAlign/VAlign into the pixel delta to apply to a draw origin so a label of a given size anchors correctly.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dx(HAlign align, double textWidth) double
The dx offset to apply to an origin x so a label of textWidth is anchored.
dy(VAlign align, double textHeight) double
The dy offset to apply to an origin y so a label of textHeight is anchored.