RadialLayout class

Center + radius for a radial chart (pie/gauge/radar/polar/sunburst).

Constructors

RadialLayout(Size size, {double scale = 0.8})
scale is the fraction of min(width,height)/2 the radius fills.

Properties

center Offset
The center of the radial chart, in pixels.
final
hashCode int
The hash code for this object.
no setterinherited
radius double
The outer radius of the radial chart, in pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointAt({required double angle, required double distance}) Offset
The point on a ray at angle (radians, 0 = +x, clockwise as y grows down) at the given distance from center.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited