PieSlice class
One wedge of a PieChart / DonutChart: its weight, fill color, and label.
- Annotations
Constructors
Properties
- color → Color
-
The fill color of the wedge.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
The human-readable label for the slice.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double
-
The slice's weight; its share of the chart is
value / sum(values).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited