ChartBounds class
The inset plotting rectangle for a cartesian chart (line/bar/scatter).
Constructors
- ChartBounds(Size size, {double padding = 0.1})
-
Insets
sizeby a fractionalpaddingon every edge (default 10%). - ChartBounds.insets(Size size, {required double left, required double top, required double right, required double bottom})
-
Insets
sizeby explicit edge insets (use when axis labels need room).
Properties
- bottom → double
-
The bottom edge of the plot rectangle.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
The height of the plot rectangle.
no setter
- left → double
-
The left edge of the plot rectangle.
no setter
- rect → Rect
-
The inset plotting rectangle, in pixels.
final
- right → double
-
The right edge of the plot rectangle.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → double
-
The top edge of the plot rectangle.
no setter
- width → double
-
The width of the plot rectangle.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited