ChartBounds class

The inset plotting rectangle for a cartesian chart (line/bar/scatter).

Constructors

ChartBounds(Size size, {double padding = 0.1})
Insets size by a fractional padding on every edge (default 10%).
ChartBounds.insets(Size size, {required double left, required double top, required double right, required double bottom})
Insets size by explicit edge insets (use when axis labels need room).

Properties

bottom double
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
no setter
left double
no setter
rect Rect
final
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
no setter
width double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited